# Keras Adaptive Softmax

[![Travis](https://travis-ci.org/CyberZHG/keras-adaptive-softmax.svg)](https://travis-ci.org/CyberZHG/keras-adaptive-softmax)
[![Coverage](https://coveralls.io/repos/github/CyberZHG/keras-adaptive-softmax/badge.svg?branch=master)](https://coveralls.io/github/CyberZHG/keras-adaptive-softmax)
[![Version](https://img.shields.io/pypi/v/keras-adaptive-softmax.svg)](https://pypi.org/project/keras-adaptive-softmax/)
![Downloads](https://img.shields.io/pypi/dm/keras-adaptive-softmax.svg)
![License](https://img.shields.io/pypi/l/keras-adaptive-softmax.svg)

![](https://img.shields.io/badge/keras-tensorflow-blue.svg)
![](https://img.shields.io/badge/keras-theano-blue.svg)
![](https://img.shields.io/badge/keras-tf.keras-blue.svg)
![](https://img.shields.io/badge/keras-tf.keras/eager-blue.svg)
![](https://img.shields.io/badge/keras-tf.keras/2.0_beta-blue.svg)

\[[中文](https://github.com/CyberZHG/keras-adaptive-softmax/blob/master/README.zh-CN.md)|[English](https://github.com/CyberZHG/keras-adaptive-softmax/blob/master/README.md)\]

## Install

```bash
pip install keras-adaptive-softmax
```

## Usage
